@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright 2001-2022 Zabbix SIA
+** Copyright 2001-2023 Zabbix SIA
 **
 ** Licensed under the Apache License, Version 2.0 (the "License");
 ** you may not use this file except in compliance with the License.
@@ -125,7 +125,7 @@ func (conn *PGConn) updateAccessTime() {
 type ConnManager struct {
 	sync.Mutex
 	connMutex      sync.Mutex
-	connections    map[string]*PGConn
+	connections    map[uri.URI]*PGConn
 	keepAlive      time.Duration
 	connectTimeout time.Duration
 	callTimeout    time.Duration
@@ -139,7 +139,7 @@ func NewConnManager(keepAlive, connectTimeout, callTimeout,
 	ctx, cancel := context.WithCancel(context.Background())
 
 	connMgr := &ConnManager{
-		connections:    make(map[string]*PGConn),
+		connections:    make(map[uri.URI]*PGConn),
 		keepAlive:      keepAlive,
 		connectTimeout: connectTimeout,
 		callTimeout:    callTimeout,
@@ -161,7 +161,7 @@ func (c *ConnManager) closeUnused() {
 		if time.Since(conn.lastTimeAccess) > c.keepAlive {
 			conn.client.Close()
 			delete(c.connections, uri)
-			Impl.Debugf("[%s] Closed unused connection: %s", Name, conn.address)
+			Impl.Debugf("[%s] Closed unused connection: %s", Name, uri.Addr())
 		}
 	}
 }
@@ -198,7 +198,7 @@ func (c *ConnManager) create(uri uri.URI, details tlsconfig.Details) (*PGConn, e
 	c.connMutex.Lock()
 	defer c.connMutex.Unlock()
 
-	if _, ok := c.connections[uri.NoQueryString()]; ok {
+	if _, ok := c.connections[uri]; ok {
 		// Should never happen.
 		panic("connection already exists")
 	}
@@ -246,7 +246,7 @@ func (c *ConnManager) create(uri uri.URI, details tlsconfig.Details) (*PGConn, e
 		return nil, fmt.Errorf("PostgreSQL version %d is not supported", serverVersion)
 	}
 
-	c.connections[uri.NoQueryString()] = &PGConn{
+	c.connections[uri] = &PGConn{
 		client:         client,
 		callTimeout:    c.callTimeout,
 		version:        serverVersion,
@@ -258,7 +258,7 @@ func (c *ConnManager) create(uri uri.URI, details tlsconfig.Details) (*PGConn, e
 
 	Impl.Debugf("[%s] Created new connection: %s", Name, uri.Addr())
 
-	return c.connections[uri.NoQueryString()], nil
+	return c.connections[uri], nil
 }
 
 func createTLSClient(dsn string, timeout time.Duration, details tlsconfig.Details) (*sql.DB, error) {
@@ -303,7 +303,7 @@ func (c *ConnManager) get(uri uri.URI) *PGConn {
 	c.connMutex.Lock()
 	defer c.connMutex.Unlock()
 
-	if conn, ok := c.connections[uri.NoQueryString()]; ok {
+	if conn, ok := c.connections[uri]; ok {
 		conn.updateAccessTime()
 		return conn
 	}
